==> hydrogen_0.8.2.orig.tar.gz: hydrogen-0.8.2/lib/Hydrogen.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2004 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://hydrogen.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: Hydrogen.h,v 1.14 2004/02/25 13:29:42 comix Exp $
 *
 */
#ifndef HYDROGEN_H
#define HYDROGEN_H

#include "Song.h"
#include "Object.h"
#include "GenericDriver.h"
#include "EngineListener.h"
#include "TransportInfo.h"


// Engine state
#define UNINITIALIZED	1
#define INITIALIZED		2
#define PREPARED		3
#define READY			4
#define PLAYING			5


// forward
class AlsaMidiDriver;

//----------------------------------------------------------------------------
/**
 * Hydrogen Audio Engine
 */
class Hydrogen : public Object
{
	public:
		/** Return the Hydrogen instance */
		static Hydrogen* getInstance(EngineListener *listener = NULL);

		/** Destructor */
		~Hydrogen();

		/** Start the internal sequencer */
		void start();

		/** Stop the internal sequencer */
		void stop();

		/** Set current song */
		void setSong(Song *newSong);

		/** Return the current song */
		Song* getSong();
		void removeSong();

		void noteOn(Note *note);
		void noteOff(Note *note);

		void addRealtimeNote (int instrument, float velocity, float pan_L=1.0, float pan_R=1.0, float pitch=0.0, bool forcePlay=false);
		
		float getMasterPeak_L();
		void setMasterPeak_L(float value);

		float getMasterPeak_R();
		void setMasterPeak_R(float value);

		void getLadspaFXPeak( int nFX, float *fL, float *fR );
		void setLadspaFXPeak( int nFX, float fL, float fR );


		unsigned long getTickPosition();
		unsigned long getRealtimeTickPosition();

		void setNextPattern(int pos);

		Pattern* getCurrentPattern();
		void setCurrentPattern(Pattern *newPattern);

		int getPatternPos();
		void setPatternPos( int pos );

		uint getPlayingNotes();

		void restartDrivers();

		uint exportSong(string filename);

		uint getSongNotesQueue();

		GenericDriver* getAudioDriver();
		AlsaMidiDriver* getMidiDriver();

		int getState();

		void addEngineListener(EngineListener *newListener);

		void lockEngine(string sLocker);
		void unlockEngine();

		float getProcessTime();
		float getMaxProcessTime();

		int loadDrumkit( DrumkitInfo *drumkitInfo );

		void raiseError(uint nErrorCode);

		void raiseMidiActivityEvent();

		unsigned long getTotalFrames();

		void previewSample( Sample *pSample );

		enum {
			NO_OSS_SUPPORT,
			NO_JACK_SUPPORT,
			UNKNOWN_DRIVER,
			ERROR_STARTING_DRIVER,
			JACK_SERVER_SHUTDOWN,
			JACK_CANNOT_ACTIVATE_CLIENT,
			JACK_CANNOT_CONNECT_OUTPUT_PORT,
			JACK_ERROR_IN_PORT_REGISTER
		};

		void setTapTempo( float fInterval );
		void setBPM( float fBPM );

		void restartLadspaFX();

	private:
		static Hydrogen* instance;

		/** Constructor */
		Hydrogen( EngineListener *mainListener );

};



#endif

==> hydrogen_0.9.1.orig.tar.gz: hydrogen-0.9.1/lib/Hydrogen.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2004 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://hydrogen.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: Hydrogen.h,v 1.17 2004/04/22 12:10:58 comix Exp $
 *
 */
#ifndef HYDROGEN_H
#define HYDROGEN_H

#include "Song.h"
#include "Object.h"
#include "drivers/GenericDriver.h"
#include "drivers/TransportInfo.h"
#include "EngineListener.h"


// Engine state
#define UNINITIALIZED	1
#define INITIALIZED		2
#define PREPARED		3
#define READY			4
#define PLAYING			5


// forward
class AlsaMidiDriver;

//----------------------------------------------------------------------------
/**
 * Hydrogen Audio Engine
 */
class Hydrogen : public Object
{
	public:
		/// Return the Hydrogen instance
		static Hydrogen* getInstance(EngineListener *listener = NULL);

		~Hydrogen();

		/// Start the internal sequencer
		void start();

		/// Stop the internal sequencer
		void stop();

		/// Set current song
		void setSong(Song *newSong);

		/// Return the current song
		Song* getSong();
		void removeSong();

		void noteOn(Note *note);
		void noteOff(Note *note);

		void addRealtimeNote (int instrument, float velocity, float pan_L=1.0, float pan_R=1.0, float pitch=0.0, bool forcePlay=false);

		float getMasterPeak_L();
		void setMasterPeak_L(float value);

		float getMasterPeak_R();
		void setMasterPeak_R(float value);

		void getLadspaFXPeak( int nFX, float *fL, float *fR );
		void setLadspaFXPeak( int nFX, float fL, float fR );


		unsigned long getTickPosition();
		unsigned long getRealtimeTickPosition();

		void setNextPattern(int pos);

		PatternList* getCurrentPatternList();
		void setCurrentPatternList(PatternList *pPatternList);

		int getPatternPos();
		void setPatternPos( int pos );

		uint getPlayingNotes();

		void restartDrivers();

		uint exportSong(string filename);

		uint getSongNotesQueue();

		GenericDriver* getAudioDriver();
		AlsaMidiDriver* getMidiDriver();

		int getState();

		void addEngineListener(EngineListener *newListener);
		void removeEngineListener(EngineListener *newListener);

		void lockEngine(string sLocker);
		void unlockEngine();

		float getProcessTime();
		float getMaxProcessTime();

		int loadDrumkit( DrumkitInfo *drumkitInfo );

		void raiseError(uint nErrorCode);

		void raiseMidiActivityEvent();

		unsigned long getTotalFrames();

		void previewSample( Sample *pSample );

		enum ErrorMessages {
			NO_OSS_SUPPORT,
			NO_JACK_SUPPORT,
			NO_ALSA_SUPPORT,
			UNKNOWN_DRIVER,
			ERROR_STARTING_DRIVER,
			JACK_SERVER_SHUTDOWN,
			JACK_CANNOT_ACTIVATE_CLIENT,
			JACK_CANNOT_CONNECT_OUTPUT_PORT,
			JACK_ERROR_IN_PORT_REGISTER
		};

		void setTapTempo( float fInterval );
		void setBPM( float fBPM );

		void restartLadspaFX();

		int getSelectedPatternNumber();
		void setSelectedPatternNumber( int nPat );

		int getSelectedInstrumentNumber();
		void setSelectedInstrumentNumber( int nInstrument );

	private:
		static Hydrogen* instance;

		/** Constructor */
		Hydrogen( EngineListener *mainListener );

};



#endif
